@@ -128,6 +128,11 @@ class ENSEMBLE(MCDA):
             if t == "a tie":
                 df_hard.iloc[a_tie.index(t), -2] = "a tie"
                 df_hard.iloc[a_tie.index(t), -1] = "a tie"
+        # set a tis by std = 1
+        for t in range(0, df_hard.shape[0]-1):
+            if df_hard.iloc[t,-3] == 1: 
+                df_hard.iloc[a_tie.index(t), -2] = "a tie"
+                df_hard.iloc[a_tie.index(t), -1] = "a tie"
 
         df_hard = pd.DataFrame(list_mcda_intances[0].df_decision.iloc[:, 0]).join(df_hard)
         
